@@ -1,7 +1,7 @@
 """ Tumblpy """
 
 __author__ = 'Mike Helmick <mikehelmick@me.com>'
-__version__ = '0.6.2'
+__version__ = '0.6.3'
 
 import requests
 from requests.auth import OAuth1
@@ -240,7 +240,7 @@ class Tumblpy(object):
 
         if response.status_code < 200 or response.status_code > 301:
             error_message = ''
-            if content.get('errors') or content.get('error'):
+            if content and (content.get('errors') or content.get('error')):
                 if 'errors' in content:
                     for error in content['errors']:
                         error_message = '%s ' % error
